GenerateCliquesCovariance: Generate a block diagonal covariance matrix
Description
This function is included in the package so that it can be used in the
example code provided in spcov.
Usage
GenerateCliquesCovariance(ncliques, cliquesize, theta)
Arguments
cliquesize
size of each block
theta
magnitude of non-zeros
Value
- Sigma
- the covariance matrix
- A
- symmetric square root of
Sigma - shift
- how much the eigenvalues were shifted. See details.
Details
This function generates a block diagonal positive definite
matrix with randomly-signed, non-zero elements. A shift is added to
the diagonal of the matrix so that its condition number equals
p, the number of variables.References
Bien, J., and Tibshirani, R. (2011), "Sparse Estimation of a Covariance Matrix," accepted for publication in Biometrika.